"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const chalk_1 = __importDefault(require("chalk"));
const DataProvider_1 = require("./DataProvider");
const DockerRunner_1 = require("./DockerRunner");
const getDockerfileURL = (language) => {
    return `https://raw.githubusercontent.com/hermes-tcc/project-building-base-images/master/${language}.Dockerfile`;
};
const getFunctionWatcherURL = () => {
    return 'github.com/hermes-tcc/function-watcher';
};
class Builder {
    constructor(fnDir, username, dockerhubUsername, opts) {
        this.buildFunction = () => __awaiter(this, void 0, void 0, function* () {
            const { data: dockerfile } = yield axios_1.default.get(getDockerfileURL(this.fnData.language));
            this.logger.log(chalk_1.default.bold.green('===== BUILD HERMES FUNCTION ======'));
            const dockerProc = DockerRunner_1.DockerRunner.run(['build', '-f', '-', '-t', this.fnData.buildName, this.fnData.functionDir], this.outputToStdout);
            dockerProc.stdin.end(dockerfile);
            yield dockerProc;
            this.logger.log(chalk_1.default.bold.green('===== HERMES FUNCTION BUILT ======\n'));
            return this.fnData.builtFunctionObj;
        });
        this.buildWatcher = (target = 'development') => __awaiter(this, void 0, void 0, function* () {
            yield this.buildFunction();
            this.logger.log(chalk_1.default.bold.green('===== BUILD WATCHER ======'));
            yield DockerRunner_1.DockerRunner.run([
                'build',
                '-t',
                this.fnData.watcherName,
                `--target=${target}`,
                '--build-arg',
                `FN_IMAGE=${this.fnData.buildName}`,
                '--build-arg',
                `FN_LANGUAGE=${this.fnData.language}`,
                getFunctionWatcherURL(),
            ], this.outputToStdout);
            this.logger.log(chalk_1.default.bold.green('===== WATCHER BUILT ======\n'));
            return this.fnData.builtWatcherObj;
        });
        const { fnData, logger, outputToStdout } = opts || {};
        this.outputToStdout = outputToStdout;
        this.logger = logger || { log: () => { } };
        this.fnData = fnData ? fnData : new DataProvider_1.DataProvider(fnDir, username, dockerhubUsername);
    }
}
exports.Builder = Builder;
//# sourceMappingURL=Builder.js.map