"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const HermesFunction_1 = require("../datasources/HermesFunction");
const Builder_1 = require("./Builder");
const DataProvider_1 = require("./DataProvider");
const DockerRunner_1 = require("./DockerRunner");
class Pusher {
    constructor(fnDir, username, dockerhubUsername, options) {
        this.addToHermes = (update, token, target = 'development') => __awaiter(this, void 0, void 0, function* () {
            const exists = yield this.checkIfFunctionExists(token);
            if (exists) {
                this.logger.log(chalk_1.default.bold(`-> The function ${chalk_1.default.green(this.fnData.functionName)} already exists.`));
                if (!update)
                    throw new Error('Function already exists and update flag is false');
                this.logger.log(chalk_1.default.bold(`-> Update function!`));
            }
            yield this.build(target);
            yield this.pushWatcherToDockerhub();
            if (exists && update)
                return yield this.updateOnHermes(token);
            return yield this.pushToHermes(token);
        });
        this.build = (target) => {
            return this.builder.buildWatcher(target);
        };
        this.pushToHermes = (token) => __awaiter(this, void 0, void 0, function* () {
            this.logger.log(chalk_1.default.bold.green('===== DEPLOY FUNCTION ON HERMES ======'));
            const fn = yield HermesFunction_1.HermesFunctionDatasource.deployFunction(this.fnData.username, this.fnData.functionObj, token);
            this.logger.log(chalk_1.default.bold.green('===== FUNCTION DEPLOYED ======'));
            return fn.newFunction;
        });
        this.updateOnHermes = (token) => __awaiter(this, void 0, void 0, function* () {
            this.logger.log(chalk_1.default.bold.green('===== UPDATE FUNCTION ON HERMES ======'));
            const fn = yield HermesFunction_1.HermesFunctionDatasource.updateFunction(this.fnData.username, this.fnData.functionID, this.fnData.functionObj, token);
            this.logger.log(chalk_1.default.bold.green('===== FUNCTION UPDATED ======'));
            return fn.updatedFunctions;
        });
        this.checkIfFunctionExists = (token) => __awaiter(this, void 0, void 0, function* () {
            try {
                yield HermesFunction_1.HermesFunctionDatasource.getFunction(this.fnData.username, this.fnData.functionID, token);
                return true;
            }
            catch (err) {
                const axiosErr = err;
                this.logger.log(axiosErr.response.data.error);
                return axiosErr.response.data.error !== 'NoSuchFunction';
            }
        });
        this.pushWatcherToDockerhub = () => __awaiter(this, void 0, void 0, function* () {
            try {
                yield DockerRunner_1.DockerRunner.run(['push', this.fnData.watcherName], this.outputToStdout);
            }
            catch (err) {
                this.logger.error(chalk_1.default.bold.red(`ERROR: Check if you're logged in to ${chalk_1.default.blue(this.fnData.dockerhubUsername)} on docker. You can do it using docker logout and docker login again`));
                throw err;
            }
            this.logger.log(chalk_1.default.bold.green(`===== IMAGE ${this.fnData.watcherName} PUSHED TO DOCKERHUB ======\n`));
        });
        const { logger, outputToStdout } = options || {};
        this.outputToStdout = outputToStdout;
        this.logger = logger || { log: () => { } };
        this.fnData = new DataProvider_1.DataProvider(fnDir, username, dockerhubUsername);
        this.builder = new Builder_1.Builder(fnDir, username, dockerhubUsername, Object.assign({ fnData: this.fnData }, options));
    }
}
exports.Pusher = Pusher;
//# sourceMappingURL=Pusher.js.map