"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const Environment_1 = require("../Environment");
const authUtils_1 = require("../utils/authUtils");
const createUrl = (username, partialFunctionID) => {
    const { functionName, functionVersion } = partialFunctionID;
    return (`/${username}/function` + (functionName ? `/${functionName}` + (functionVersion ? `/${functionVersion}` : '') : ''));
};
class HermesFunctionDatasource {
    static get baseURL() {
        return Environment_1.Environment.baseURL + '/user';
    }
    static getFunction(username, partialFunctionID, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const clientRes = yield this.client.get(this.baseURL + createUrl(username, partialFunctionID), {
                    headers: authUtils_1.getAuthorizationHeader(token),
                });
                return clientRes.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static deleteFunction(username, partialFunctionID, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const clientRes = yield this.client.delete(this.baseURL + createUrl(username, partialFunctionID), {
                    headers: authUtils_1.getAuthorizationHeader(token),
                });
                return clientRes.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static deployFunction(username, hermesFunction, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const clientRes = yield this.client.post(this.baseURL + `/${username}/function`, hermesFunction, {
                    headers: authUtils_1.getAuthorizationHeader(token),
                });
                return clientRes.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static updateFunction(username, partialFunctionID, updatedHermesFunction, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const clientRes = yield this.client.put(this.baseURL + createUrl(username, partialFunctionID), updatedHermesFunction, {
                    headers: authUtils_1.getAuthorizationHeader(token),
                });
                return clientRes.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
}
HermesFunctionDatasource.client = axios_1.default.create();
exports.HermesFunctionDatasource = HermesFunctionDatasource;
//# sourceMappingURL=HermesFunction.js.map