"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const stream_utils_1 = require("@hermes-serverless/stream-utils");
const axios_1 = __importDefault(require("axios"));
const request_1 = __importDefault(require("request"));
const Environment_1 = require("../Environment");
const authUtils_1 = require("../utils/authUtils");
const querystring_1 = __importDefault(require("querystring"));
const createFunctionRunsUrl = (username, partialFunctionID) => {
    const { functionOwner, functionName, functionVersion } = partialFunctionID;
    return (`/${username}/function-runs/${functionOwner}` +
        (functionName ? `/${functionName}` + (functionVersion ? `/${functionVersion}` : '') : ''));
};
const createRunsUrl = (username, { id }) => {
    return `/${username}/runs` + (id ? `/${id}` : '');
};
class RunDatasource {
    static get baseURL() {
        return Environment_1.Environment.baseURL + '/user';
    }
    static getRuns(username, runID, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const clientRes = yield this.client.get(this.baseURL + createRunsUrl(username, runID), {
                    headers: authUtils_1.getAuthorizationHeader(token),
                });
                return clientRes.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static deleteRun(username, runID, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const clientRes = yield this.client.delete(this.baseURL + createRunsUrl(username, runID), {
                    headers: authUtils_1.getAuthorizationHeader(token),
                });
                return clientRes.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static getFunctionRuns(username, functionID, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const clientRes = yield this.client.get(this.baseURL + createFunctionRunsUrl(username, functionID), {
                    headers: authUtils_1.getAuthorizationHeader(token),
                });
                return clientRes.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static deleteFunctionRuns(username, functionID, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const clientRes = yield this.client.delete(this.baseURL + createFunctionRunsUrl(username, functionID), {
                    headers: authUtils_1.getAuthorizationHeader(token),
                });
                return clientRes.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static createAsyncRun(username, functionID, input, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { functionOwner, functionName, functionVersion } = functionID;
                const res = yield this.client.post(this.baseURL + `/${username}/run/${functionOwner}/${functionName}/${functionVersion}`, input, {
                    headers: Object.assign({}, authUtils_1.getAuthorizationHeader(token), { 'x-hermes-run-type': 'async' }),
                });
                return res.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static createSyncRun(username, functionID, input, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { functionOwner, functionName, functionVersion } = functionID;
                const res = request_1.default.post(this.baseURL + `/${username}/run/${functionOwner}/${functionName}/${functionVersion}`, {
                    headers: Object.assign({}, authUtils_1.getAuthorizationHeader(token), { 'x-hermes-run-type': 'sync' }),
                });
                if (typeof input === 'string') {
                    const stream = new stream_utils_1.StringStream(input);
                    stream.pipe(res);
                }
                else
                    input.pipe(res);
                return res;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static getRunStatus(username, runID, token, additionalFields) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const url = this.baseURL + `/${username}/run/${runID}/status?` + querystring_1.default.encode(Object.assign({}, (additionalFields || [])));
                const res = yield this.client.get(url, {
                    headers: Object.assign({}, authUtils_1.getAuthorizationHeader(token)),
                });
                return res.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static getRunResultInfo(username, runID, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const url = this.baseURL + `/${username}/run/${runID}/result-info`;
                const res = yield this.client.get(url, {
                    headers: Object.assign({}, authUtils_1.getAuthorizationHeader(token)),
                });
                return res.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    static getRunResultOutput(username, runID, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const url = this.baseURL + `/${username}/run/${runID}/result-output`;
                const res = yield this.client.get(url, {
                    headers: Object.assign({}, authUtils_1.getAuthorizationHeader(token)),
                });
                return res.data;
            }
            catch (err) {
                throw err;
            }
        });
    }
}
RunDatasource.client = axios_1.default.create();
exports.RunDatasource = RunDatasource;
//# sourceMappingURL=Run.js.map