"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
exports.parseHermesConfig = (dir) => {
    const hermesPath = path_1.default.join(dir, 'hermes.config.json');
    if (!fs_1.default.existsSync(hermesPath)) {
        console.log(chalk_1.default.bold.red("This directory doesn't have a hermes.config.json"));
        process.exit(1);
    }
    const hermesConf = JSON.parse(fs_1.default.readFileSync(hermesPath, { encoding: 'utf-8' }));
    const fields = ['functionName', 'functionVersion', 'gpuCapable', 'language', 'scope', 'handler'];
    const err = [];
    fields.forEach((field) => {
        if (hermesConf[field] == null) {
            err.push(chalk_1.default.bold.red(`Missing field ${field} on hermes.config.json`));
        }
    });
    if (err.length !== 0) {
        err.forEach(msg => console.log(msg));
        process.exit(1);
    }
    const versionReg = /^([0-9]+\.)([0-9]+\.)([0-9])$/;
    if (!versionReg.test(hermesConf.functionVersion)) {
        console.log(chalk_1.default.bold.red(`Use [number].[number].[number] pattern for versioning`));
        process.exit(1);
    }
    const nameReg = /^[a-z0-9_]+[a-z0-9_\-]*$/;
    if (!nameReg.test(hermesConf.functionName)) {
        console.log(chalk_1.default.bold.red(`Use only lowercase letters, numbers, hyphens and underlines for function name. Don't start function name with hyphen`));
        process.exit(1);
    }
    return hermesConf;
};
//# sourceMappingURL=functionUtils.js.map